/**********************************************************************
Copyright (c) 2011 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
   ...
**********************************************************************/
package org.datanucleus.store.json;

import org.datanucleus.metadata.AbstractClassMetaData;
import org.datanucleus.metadata.AbstractMemberMetaData;
import org.datanucleus.metadata.ColumnMetaData;
import org.datanucleus.metadata.VersionMetaData;

/**
 * Convenience methods for JSON.
 */
public class JSONUtils
{
    /**
     * Method to return the member name to use in JSON.
     * Uses the column name if provided, otherwise the member name from the class.
     * @param mmd Metadata for the member
     * @return The JSON member name
     */
    public static String getMemberNameForMember(AbstractMemberMetaData mmd)
    {
        String name = mmd.getName();
        ColumnMetaData[] colmds = mmd.getColumnMetaData();
        if (colmds != null && colmds.length == 1 && colmds[0].getName() != null)
        {
            name = colmds[0].getName();
        }
        return name;
    }

    /**
     * Method to return the member name to be used by JSON for the datastore identity of the object.
     * @param cmd Metadata for the class
     * @return The member name for the (datastore) identity
     */
    public static String getMemberNameForDatastoreIdentity(AbstractClassMetaData cmd)
    {
        String name = "IDENTITY";
        if (cmd.getIdentityMetaData() != null && cmd.getIdentityMetaData().getColumnMetaData() != null)
        {
            name = cmd.getIdentityMetaData().getColumnMetaData().getName();
        }
        return name;
    }

    /**
     * Method to return the member name to be used by JSON for the version of the object.
     * @param vermd Version metadata
     * @return The member name
     */
    public static String getMemberNameForVersion(VersionMetaData vermd)
    {
        String name = "VERSION";
        ColumnMetaData colmd = vermd.getColumnMetaData();
        if (colmd != null && colmd.getName() != null)
        {
            name = colmd.getName();
        }
        return name;
    }
}